@@ -31,6 +31,12 @@ sub get_formatter_by_name {
 sub get_formatter_by_type {
     my ($class, $type) = @_;
     return unless $type;
+
+    # If content-type includes subtype, top-level media type is only used.
+    if ($type =~ /;/){
+        $type = $`;
+    }
+
     return $FORMATTERS_BY_TYPE{$type};
 }
 
@@ -56,8 +62,12 @@ This library leaves the other formatters for interop.
 
 =head2 get_formatter_by_name( $name )
 
+return formatter by name
+
 =head2 get_formatter_by_type( $content_type )
 
+return formatter by content type
+
 =head1 SEE ALSO
 
 L<OAuth::Lite2::Formatter>
